{% extends "base.html" %}
{% load i18n %}
{% block header %}{% endblock %}
{% block page_role %}data-role="dialog"{% endblock %}
{% block content %}
    <div data-role="header">
        <h1>{% trans 'Really Delete?' %}</h1>
    </div>
    <div data-role="content" title="{% trans 'Really Delete?' %}">
        <a href="{% url "sp_profile_edit_page" %}" data-role="button" data-theme="b">{% trans "Keep Account" %}</a>
        <br>
        <form action="{% url "sp_delete_page" %}" method="post" data-ajax="false">
            {% csrf_token %}
            <input type="submit" data-theme="e" data-mini="true" value="{% trans 'Delete Account & All Data' %}">
        </form>
    </div>
{% endblock %}
{% block footer %}{% endblock %}